referrerpolicy=no-referrer-when-downgrade

GenesisSlot

Type Alias GenesisSlot 

pub type GenesisSlot<T> = StorageValue<_GeneratedPrefixForStorageGenesisSlot<T>, Slot, ValueQuery>;
First block slot number.

As the slots may not be zero-based, we record the slot value for the fist block. This allows to always compute relative indices for epochs and slots.

Storage type is [StorageValue] with value type Slot.

Aliased Type

pub struct GenesisSlot<T>(/* private fields */);